@@ -13,6 +13,13 @@ use Zend\Code\Annotation\AnnotationManager;
 use Zend\Code\Exception;
 use Zend\Code\NameInformation;
 
+use function array_shift;
+use function array_slice;
+use function in_array;
+use function is_array;
+use function is_int;
+use function is_string;
+
 class TokenArrayScanner implements ScannerInterface
 {
     /**
@@ -28,12 +35,12 @@ class TokenArrayScanner implements ScannerInterface
     /**
      * @var null
      */
-    protected $docComment = null;
+    protected $docComment;
 
     /**
      * @var NameInformation
      */
-    protected $nameInformation = null;
+    protected $nameInformation;
 
     /**
      * @var array
@@ -43,7 +50,7 @@ class TokenArrayScanner implements ScannerInterface
     /**
      * @var AnnotationManager
      */
-    protected $annotationManager = null;
+    protected $annotationManager;
 
     /**
      * @param null|array $tokens
@@ -118,7 +125,7 @@ class TokenArrayScanner implements ScannerInterface
     }
 
     /**
-     * @return array
+     * @return void
      */
     public function getIncludes()
     {
@@ -189,7 +196,7 @@ class TokenArrayScanner implements ScannerInterface
                 }
             }
 
-            if (!$classFound) {
+            if (! $classFound) {
                 return false;
             }
         }
@@ -198,7 +205,7 @@ class TokenArrayScanner implements ScannerInterface
             array_slice(
                 $this->tokens,
                 $info['tokenStart'],
-                ($info['tokenEnd'] - $info['tokenStart'] + 1)
+                $info['tokenEnd'] - $info['tokenStart'] + 1
             ), // zero indexed array
             new NameInformation($info['namespace'], $info['uses'])
         );
@@ -220,11 +227,11 @@ class TokenArrayScanner implements ScannerInterface
             }
         }
 
-        if (!$classFound) {
+        if (! $classFound) {
             return false;
         }
 
-        if (!isset($info)) {
+        if (! isset($info)) {
             return;
         }
 
@@ -255,11 +262,11 @@ class TokenArrayScanner implements ScannerInterface
         $this->scan();
 
         $functions = [];
-        foreach ($this->infos as $info) {
-            if ($info['type'] == 'function') {
-                // @todo $functions[] = new FunctionScanner($info['name']);
-            }
-        }
+//        foreach ($this->infos as $info) {
+//            if ($info['type'] == 'function') {
+//                // @todo $functions[] = new FunctionScanner($info['name']);
+//            }
+//        }
 
         return $functions;
     }
@@ -267,7 +274,7 @@ class TokenArrayScanner implements ScannerInterface
     /**
      * Export
      *
-     * @param $tokens
+     * @param mixed $tokens
      */
     public static function export($tokens)
     {
@@ -294,14 +301,13 @@ class TokenArrayScanner implements ScannerInterface
             return;
         }
 
-        if (!$this->tokens) {
+        if (! $this->tokens) {
             throw new Exception\RuntimeException('No tokens were provided');
         }
 
         /**
          * Variables & Setup
          */
-
         $tokens          = &$this->tokens; // localize
         $infos           = &$this->infos; // localize
         $tokenIndex      = null;
@@ -324,8 +330,8 @@ class TokenArrayScanner implements ScannerInterface
             &$tokenContent,
             &$tokenLine
         ) {
-            $tokenIndex = ($tokenIndex === null) ? 0 : $tokenIndex + 1;
-            if (!isset($tokens[$tokenIndex])) {
+            $tokenIndex = $tokenIndex === null ? 0 : $tokenIndex + 1;
+            if (! isset($tokens[$tokenIndex])) {
                 $token        = false;
                 $tokenContent = false;
                 $tokenType    = false;
@@ -336,7 +342,7 @@ class TokenArrayScanner implements ScannerInterface
             if (is_string($tokens[$tokenIndex]) && $tokens[$tokenIndex] === '"') {
                 do {
                     $tokenIndex++;
-                } while (!(is_string($tokens[$tokenIndex]) && $tokens[$tokenIndex] === '"'));
+                } while (! (is_string($tokens[$tokenIndex]) && $tokens[$tokenIndex] === '"'));
             }
             $token = $tokens[$tokenIndex];
             if (is_array($token)) {
@@ -349,7 +355,7 @@ class TokenArrayScanner implements ScannerInterface
             return $tokenIndex;
         };
         $MACRO_TOKEN_LOGICAL_START_INDEX = function () use (&$tokenIndex, &$docCommentIndex) {
-            return ($docCommentIndex === false) ? $tokenIndex : $docCommentIndex;
+            return $docCommentIndex === false ? $tokenIndex : $docCommentIndex;
         };
         $MACRO_DOC_COMMENT_START = function () use (&$tokenIndex, &$docCommentIndex) {
             $docCommentIndex = $tokenIndex;
@@ -361,7 +367,7 @@ class TokenArrayScanner implements ScannerInterface
             if ($validTrailingTokens === null) {
                 $validTrailingTokens = [T_WHITESPACE, T_FINAL, T_ABSTRACT, T_INTERFACE, T_CLASS, T_FUNCTION];
             }
-            if ($docCommentIndex !== false && !in_array($tokenType, $validTrailingTokens)) {
+            if ($docCommentIndex !== false && ! in_array($tokenType, $validTrailingTokens)) {
                 $docCommentIndex = false;
             }
 
@@ -378,7 +384,6 @@ class TokenArrayScanner implements ScannerInterface
         /**
          * START FINITE STATE MACHINE FOR SCANNING TOKENS
          */
-
         // Initialize token
         $MACRO_TOKEN_ADVANCE();
 
@@ -414,7 +419,7 @@ class TokenArrayScanner implements ScannerInterface
 
                 SCANNER_NAMESPACE_TOP:
 
-                if ($tokenType === null && $tokenContent === ';' || $tokenContent === '{') {
+                if (($tokenType === null && $tokenContent === ';') || $tokenContent === '{') {
                     goto SCANNER_NAMESPACE_END;
                 }
 
@@ -449,8 +454,12 @@ class TokenArrayScanner implements ScannerInterface
                     'lineStart'  => $tokens[$tokenIndex][2],
                     'lineEnd'    => null,
                     'namespace'  => $namespace,
-                    'statements' => [0 => ['use' => null,
-                                                     'as'  => null]],
+                    'statements' => [
+                        0 => [
+                            'use' => null,
+                            'as'  => null,
+                        ],
+                    ],
                 ];
 
                 $useStatementIndex = 0;
@@ -469,8 +478,10 @@ class TokenArrayScanner implements ScannerInterface
                     } elseif ($tokenContent === ',') {
                         $useAsContext = false;
                         $useStatementIndex++;
-                        $infos[$infoIndex]['statements'][$useStatementIndex] = ['use' => null,
-                                                                                     'as'  => null];
+                        $infos[$infoIndex]['statements'][$useStatementIndex] = [
+                            'use' => null,
+                            'as'  => null,
+                        ];
                     }
                 }
 
@@ -512,7 +523,7 @@ class TokenArrayScanner implements ScannerInterface
                     T_INCLUDE      => 'include',
                     T_INCLUDE_ONCE => 'include_once',
                     T_REQUIRE      => 'require',
-                    T_REQUIRE_ONCE => 'require_once'
+                    T_REQUIRE_ONCE => 'require_once',
                 ];
 
                 $infos[$infoIndex] = [
@@ -558,7 +569,7 @@ class TokenArrayScanner implements ScannerInterface
             case T_INTERFACE:
             case T_TRAIT:
                 $infos[$infoIndex] = [
-                    'type'        => ($tokenType === T_FUNCTION) ? 'function' : 'class',
+                    'type'        => $tokenType === T_FUNCTION ? 'function' : 'class',
                     'tokenStart'  => $MACRO_TOKEN_LOGICAL_START_INDEX(),
                     'tokenEnd'    => null,
                     'lineStart'   => $tokens[$tokenIndex][2],
@@ -583,8 +594,10 @@ class TokenArrayScanner implements ScannerInterface
                         && $infos[$infoIndex]['type'] === 'class'
                         || ($tokenType === T_FUNCTION && $infos[$infoIndex]['type'] === 'function'))
                 ) {
-                    $infos[$infoIndex]['shortName'] = $tokens[$tokenIndex + 2][1];
-                    $infos[$infoIndex]['name']      = (($namespace !== null)
+                    $infos[$infoIndex]['shortName'] = is_array($tokens[$tokenIndex + 2])
+                        ? $tokens[$tokenIndex + 2][1]
+                        : $tokens[$tokenIndex + 2];
+                    $infos[$infoIndex]['name']      = ($namespace !== null
                         ? $namespace . '\\'
                         : '') . $infos[$infoIndex]['shortName'];
                 }
@@ -627,7 +640,6 @@ class TokenArrayScanner implements ScannerInterface
         /**
          * END FINITE STATE MACHINE FOR SCANNING TOKENS
          */
-
         $this->isScanned = true;
     }
 
@@ -651,7 +663,7 @@ class TokenArrayScanner implements ScannerInterface
 
     /**
      * @param  string $namespace
-     * @return null|array
+     * @return void|array
      * @throws Exception\InvalidArgumentException
      */
     protected function getUsesNoScan($namespace)
@@ -665,9 +677,9 @@ class TokenArrayScanner implements ScannerInterface
 
         if ($namespace === null) {
             $namespace = array_shift($namespaces);
-        } elseif (!is_string($namespace)) {
+        } elseif (! is_string($namespace)) {
             throw new Exception\InvalidArgumentException('Invalid namespace provided');
-        } elseif (!in_array($namespace, $namespaces)) {
+        } elseif (! in_array($namespace, $namespaces)) {
             return;
         }
 
